@@ -109,10 +109,9 @@ ctx = _Context
 
 
 def set_request_id(request: Request, response: Response):
-    cloud_trace_context = request.get_header('X-CLOUD-TRACE-CONTEXT', '')
-    match = re.fullmatch(_TRACE_CONTEXT_HEADER_RE, cloud_trace_context)
+    cloud_trace_context = request.get_header('X-CLOUD-TRACE-CONTEXT', None)
 
-    if match is None:
+    if not cloud_trace_context:
         ctx.trace_id = str(uuid4())
         ctx.span_id = str(random.randint(1000000000000000000, 9999999999999999999))
         ctx.trace_flags = 'o=1'
@@ -120,6 +119,7 @@ def set_request_id(request: Request, response: Response):
         ctx.x_cloud_trace_context = \
             f'{ctx.trace_id}/{ctx.span_id};{ctx.trace_flags}'
     else:
+        match = re.fullmatch(_TRACE_CONTEXT_HEADER_RE, cloud_trace_context)
         ctx.trace_id = match.group("trace_id")
         ctx.span_id = match.group("span_id")
         ctx.trace_flags = match.group("trace_flags")
